@@ -28,7 +28,7 @@ author = 'Christoph Zwerschke et al.'
 # The short X.Y version
 version = '3.0'
 # The full version, including alpha/beta/rc tags
-release = '3.0.7'
+release = '3.0.8'
 
 
 # -- General configuration ---------------------------------------------------
@@ -64,8 +64,7 @@ autosummary_generate = True
 # (references to some Python built-in types do not resolve correctly)
 nitpicky = True
 nitpick_ignore = [('py:class', t) for t in (
-    'cgi.FieldStorage', 'html.parser.HTMLParser',
-    'threading.Thread', 'xmlrpc.client.ProtocolError')]
+    'html.parser.HTMLParser', 'threading.Thread', 'xmlrpc.client.ProtocolError')]
 
 # -- Options for HTML output -------------------------------------------------
 
