@@ -1,6 +1,5 @@
 """HTTP requests"""
 
-import cgi
 import os
 import sys
 import traceback
@@ -11,7 +10,7 @@ from http.cookies import SimpleCookie as Cookie
 import HTTPResponse
 
 from MiscUtils import NoDefault
-from WebUtils import FieldStorage
+from WebUtils.FieldStorage import FieldStorage
 from Request import Request
 
 debug = False
@@ -36,19 +35,19 @@ class HTTPRequest(Request):
             self._requestID = requestDict['requestID']
             # Protect the loading of fields with an exception handler,
             # because bad headers sometimes can break the field storage
-            # (see also https://bugs.python.org/issue27777).
+            # (see also https://github.com/python/cpython/issues/71964).
             try:
-                self._fields = FieldStorage.FieldStorage(
+                self._fields = FieldStorage(
                     self._input, environ=self._environ,
                     keep_blank_values=True, strict_parsing=False)
             except Exception:
-                self._fields = cgi.FieldStorage(keep_blank_values=True)
+                self._fields = FieldStorage(keep_blank_values=True)
                 traceback.print_exc(file=sys.stderr)
             self._cookies = Cookie()
             if 'HTTP_COOKIE' in self._environ:
                 # If there are duplicate cookies, always use the first one
                 # because it is the most relevant one according to RFC 2965
-                # (workaround for https://bugs.python.org/issue1375011).
+                # (see also https://github.com/python/cpython/issues/42664).
                 # noinspection PyTypeChecker
                 cookies = dict(cookie.split('=', 1) for cookie in reversed(
                     self._environ['HTTP_COOKIE'].split('; ')))
@@ -64,7 +63,7 @@ class HTTPRequest(Request):
             self._time = time()
             self._environ = os.environ.copy()
             self._input = None
-            self._fields = cgi.FieldStorage(keep_blank_values=True)
+            self._fields = FieldStorage(keep_blank_values=True)
             self._cookies = Cookie()
 
         env = self._environ
@@ -131,8 +130,8 @@ class HTTPRequest(Request):
 
         # We use Tim O'Malley's Cookie class to get the cookies,
         # but then change them into an ordinary dictionary of values
-        self._cookies = dict(
-            (key, self._cookies[key].value) for key in self._cookies)
+        self._cookies = {
+            key: self._cookies[key].value for key in self._cookies}
 
         self._contextName = None
         self._serverSidePath = self._serverSideContextPath = None
@@ -322,7 +321,7 @@ class HTTPRequest(Request):
 
         This is actually the same as pathInfo().
 
-        For example, http://host/Webware/Context/Servlet?x=1
+        For example, https://host/Webware/Context/Servlet?x=1
         yields '/Context/Servlet'.
         """
         return self._pathInfo
@@ -330,7 +329,7 @@ class HTTPRequest(Request):
     def urlPathDir(self):
         """Same as urlPath, but only gives the directory.
 
-        For example, http://host/Webware/Context/Servlet?x=1
+        For example, https://host/Webware/Context/Servlet?x=1
         yields '/Context'.
         """
         return os.path.dirname(self.urlPath())
@@ -435,7 +434,7 @@ class HTTPRequest(Request):
         then the canonical hostname of the server is used if possible.
 
         The path is returned without any extra path info or query strings,
-        i.e. http://www.my.own.host.com:8080/Webware/TestPage.py
+        i.e. https://www.my.own.host.com:8080/Webware/TestPage.py
         """
         if canonical and 'SCRIPT_URI' in self._environ:
             return self._environ['SCRIPT_URI']
@@ -802,7 +801,8 @@ class HTTPRequest(Request):
         ]
         for method in _infoMethods:
             try:
-                info.append((method.__name__, method(self)))
+                # noinspection PyArgumentList
+                info.append((method.__name__, method(self),))
             except Exception:
                 info.append((method.__name__, None))
         return info
