@@ -187,6 +187,8 @@ class FieldStorage:
             ctype, pdict = 'application/x-www-form-urlencoded', {}
         self.type = ctype
         self.type_options = pdict
+        if not self._binary_file and isBinaryType(ctype, pdict):
+            self._binary_file = True
         self.innerboundary = pdict['boundary'].encode(
             self.encoding, self.errors) if 'boundary' in pdict else b''
 
@@ -416,7 +418,6 @@ class FieldStorage:
 
     def read_binary(self):
         """Internal: read binary data."""
-        self.file = self.make_file()
         todo = self.length
         while todo > 0:
             data = self.fp.read(min(todo, self.bufsize))
@@ -428,10 +429,14 @@ class FieldStorage:
             if not data:
                 self.done = -1
                 break
-            if self._binary_file:
-                self.file.write(data)
-            else:  # fix for issue 27777
-                self.file.write(data.decode())
+            if not self._binary_file:
+                # fix for https://github.com/python/cpython/issues/71964
+                try:
+                    data = data.decode()
+                except UnicodeDecodeError:
+                    self._binary_file = True
+            self.file = self.make_file()
+            self.file.write(data)
             todo -= len(data)
 
     def read_lines(self):
@@ -634,3 +639,13 @@ def hasSeparator():
     except TypeError:  # Python < 3.9.2
         return False
     return True
+
+
+def isBinaryType(ctype, pdict=None):
+    """"Check whether the given MIME type uses binary data."""
+    if pdict and pdict.get('charset') == 'binary':
+        return True
+    return not (
+        ctype.startswith('text/') or ctype.endswith(('+json', '+xml')) or
+        (ctype.startswith('application') and
+         ctype.endswith(('/json', '/xml', '/ecmascript', '/javascript'))))
